# Introduction

This is analysis code package for FRIB iFDS (FRIB Decay Staion initiative) experiment e21061. 

My personal analysis logbook can be found in [Here](https://fsu-my.sharepoint.com/:p:/g/personal/rtang_fsu_edu/EdnWBI0J1g9FovvbKVvvgHoBoHy1rokedIF7f-Sr9XA6aA). The experimental setup can also be found there. 

The elog can be found in [Here](https://fsunuc.physics.fsu.edu/elog/2022_05_e21062_FRIB/)

Other information of the experiment can be found [Here](https://fsunuc.physics.fsu.edu/wiki/index.php/FRIB_FDSi_e21062)

# Programs

### convertPixie.sh

convert NSCL-evt (raw data) to pixie-evt, ripe off the NSCL header.

### convertRoot.sh

convert pixie-evt to root with event building and mapping.h applied.

### mapping.h

Thsi define the mapping

### peachCake.C/h

Analysis class from TSelector. It do the primary analysis and apply corrections. It has option to output a new root file (with prefix "zzz_") with tree branches:

- eventID | eventID 
- runID | runID
- AoQ  | A/Q value of PID
- Z    | Z value of PID
- crossTime | cross scint. T2 analog time
- crossEnergy | croos scint. T2 analog energy
- flag | event identification flag, +1 = has Beta, +2 = has Ions, +4 = has Beam
- vetoFlag | veto, +1 = has Front trigger, +2 = has Rear trigger, +4 = has cross scint T2/B2 
- xIons | x-pos of Ions
- yIons | y-pos of Ions
- xBeta | x-pos of beta
- yBeta | y-pos of beta
- dyIonsTime | dinode Ions time 
- dyBetaTime | dinode Beta time
- veto_f  | front veto detector energy
- veto_r  | rear veto detector energy

### DecayFinder.C/h

The DecayFinder.C/h analysis the zzz_XXX files to obtain the decay curve for various isotopes. 

### PIDCutCreator.C and PIDCutChecker.C

Create/Check the PID cut.

### scipt.C

root macro to run analysis flow at once.

# Analysis Flow

1. The NSCL-evt file to pixie-evt file (nscl2pixie)
2. Use the EventBuilder to build event and apply the mapping.h
3. Use peachCake.C/h to analysis and output a new root file. 
4. Use DecayFinder.C/h to obtain the decay histogram. 


# inside the Armory

### DataBlock.h
This defines a class **DataBlock** to store data from pixie digitizer

### nsclEvtReader.h

This defines a class **NSCLEvtReader** to read NSCL evt file.

### nscl2pixie

This is a program to convert NSCL-evt file to evt file. Basically ripe out all NSCL header.

The bash script **converPixie.sh** use this program to batch convert NSCL-evt to evt file.

### evtReader.h

This defines a class **evtReader** to read pixie evt file.

### EventBuilder

This is a program to convert pixie-evt to root file with event building. This program will apply the mapping.h. The output tree has branches

1. evtID | event ID, unsigned int
2. multi | event multiplicity, int
3. detID | detector ID defined in mapping.h, int 
4. e     | energy, double
5. e_t   | timestamp, ULong64_t
6. cfd   | fine time from cfd, int
7. qdc   | 8-section of intergrated trace, int[8]
8. multiClover | multiplicity of Clover 
9. multiBeam  | multiplicity of beam-line detector
10. runID | runID, e.g. run-0330-17 = 330*100 + 17 = 33017
